package de.intevation.flys.importer;

import java.math.BigDecimal;

import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.MorphologicalWidth;
import de.intevation.flys.model.MorphologicalWidthValue;


public class ImportMorphWidthValue {

    private static Logger log = Logger.getLogger(ImportMorphWidthValue.class);


    protected MorphologicalWidthValue peer;

    protected BigDecimal station;
    protected BigDecimal width;

    protected String description;


    public ImportMorphWidthValue(
        BigDecimal station,
        BigDecimal width,
        String     description
    ) {
        this.station     = station;
        this.width       = width;
        this.description = description;
    }


    public void storeDependencies(MorphologicalWidth parent) {
        log.info("store dependencies");

        getPeer(parent);
    }


    public MorphologicalWidthValue getPeer(MorphologicalWidth parent) {
        log.info("get peer");

        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();

            Query query = session.createQuery(
                "from MorphologicalWidthValue where " +
                "   morphologicalWidth=:morphologicalWidth and " +
                "   station=:station and " +
                "   width=:width and " +
                "   description=:description");

            query.setParameter("morphologicalWidth", parent);
            query.setParameter("station", station);
            query.setParameter("width", width);
            query.setParameter("description", description);

            List<MorphologicalWidthValue> values = query.list();

            if (values.isEmpty()) {
                log.debug("Create new MorphologicalWidthValue DB instance.");

                peer = new MorphologicalWidthValue(
                    parent,
                    station,
                    width,
                    description
                );

                session.save(peer);
            }
            else {
                peer = values.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
